# SecureSendApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**changeSecureSendUserPassword**](SecureSendApi.md#changeSecureSendUserPassword) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 
[**createOrUpdateSecureSendUser**](SecureSendApi.md#createOrUpdateSecureSendUser) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username} | 
[**getSecureSendUserList**](SecureSendApi.md#getSecureSendUserList) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users | 
[**getSecureSendUserSingleSignOnLink**](SecureSendApi.md#getSecureSendUserSingleSignOnLink) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password | 

<a name="changeSecureSendUserPassword"></a>
# **changeSecureSendUserPassword**
> InlineResponse201 changeSecureSendUserPassword(accountId, namespaceId, username, body, cookie)



You can do this with the User Update function, above. We provide a simple, direct method here as well. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.SecureSendApi;


SecureSendApi apiInstance = new SecureSendApi();
String accountId = "accountId_example"; // String | 
String namespaceId = "namespaceId_example"; // String | 
String username = "username_example"; // String | 
UsernamePasswordBody1 body = new UsernamePasswordBody1(); // UsernamePasswordBody1 | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.changeSecureSendUserPassword(accountId, namespaceId, username, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling SecureSendApi#changeSecureSendUserPassword");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **namespaceId** | **String**|  |
 **username** | **String**|  |
 **body** | [**UsernamePasswordBody1**](UsernamePasswordBody1.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="createOrUpdateSecureSendUser"></a>
# **createOrUpdateSecureSendUser**
> InlineResponse201 createOrUpdateSecureSendUser(accountId, namespaceId, username, body, cookie)



Create a new SecureSend User in a specific NameSpace. This function also validates the user’s account so the user does not have to do anything (like checking a link in his/her email) to start using the account.  If an account already exists for the specified user, then this request will merely update the user’s account, changing any data passed through. The “username” must be the email address (which is also the login) of the user to be created or updated.  When updating a user, request parameters omitted will not be updated. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.SecureSendApi;


SecureSendApi apiInstance = new SecureSendApi();
String accountId = "accountId_example"; // String | 
String namespaceId = "namespaceId_example"; // String | 
String username = "username_example"; // String | 
UsersUsernameBody1 body = new UsersUsernameBody1(); // UsersUsernameBody1 | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.createOrUpdateSecureSendUser(accountId, namespaceId, username, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling SecureSendApi#createOrUpdateSecureSendUser");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **namespaceId** | **String**|  |
 **username** | **String**|  |
 **body** | [**UsersUsernameBody1**](UsersUsernameBody1.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="getSecureSendUserList"></a>
# **getSecureSendUserList**
> InlineResponse20073 getSecureSendUserList(accountId, namespaceId, cookie)



Return a list of all users in this NameSpace. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.SecureSendApi;


SecureSendApi apiInstance = new SecureSendApi();
String accountId = "accountId_example"; // String | 
String namespaceId = "namespaceId_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20073 result = apiInstance.getSecureSendUserList(accountId, namespaceId, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling SecureSendApi#getSecureSendUserList");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **namespaceId** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20073**](InlineResponse20073.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureSendUserSingleSignOnLink"></a>
# **getSecureSendUserSingleSignOnLink**
> InlineResponse20072 getSecureSendUserSingleSignOnLink(accountId, namespaceId, username, ip, theme, cookie)



Create a URL that the user can click on which will automatically log the user into the SecureSend Interface without needing to enter his/her username and password. For example, if the user has already authenticated him/herself in your system, you can use this API call to get a link that can be presented to the user so the user can then access SecureSend without needing to login again (e.g. “single sign-on”).  Note 1. This API call returns a URL. You can have the user click on that URL or you can redirect him/her to it. 2. This URL is valid for 15 minutes from the time of issuance. It can be used multiple times while it is in use. 3. These URLs are invalidated if the user’s password is changed. 4. These URLs will only work for someone coming from the IP address that your specified in your request for the URL. 5. All logins via Single Sign-on are logged in the user’s History and are denoted as Single Sign-on logins therein.   {{ACL: Account: SecureSend Single Sign-On}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.SecureSendApi;


SecureSendApi apiInstance = new SecureSendApi();
String accountId = "accountId_example"; // String | 
String namespaceId = "namespaceId_example"; // String | 
String username = "username_example"; // String | 
String ip = "ip_example"; // String | The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP.
Integer theme = 56; // Integer | The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.<br><br>Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error.
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20072 result = apiInstance.getSecureSendUserSingleSignOnLink(accountId, namespaceId, username, ip, theme, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling SecureSendApi#getSecureSendUserSingleSignOnLink");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **namespaceId** | **String**|  |
 **username** | **String**|  |
 **ip** | **String**| The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP. | [optional]
 **theme** | **Integer**| The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.&lt;br&gt;&lt;br&gt;Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error. | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20072**](InlineResponse20072.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

